<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Photo Gallery directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2016.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->
<!---
/* *************************************************************** */
Author:
	PaperThin, Inc.
	M. Carroll
Name:
	photo_category_render.cfc
Summary:
	Properties file for the Photo Gallery app field to select the records
		from the Photo Category element.
History:
 	2012-07-11 - MFC - Created
	2015-07-13 - DJM - Converted to CFC
--->
<cfcomponent displayName="PhotoCategory Render" extends="ADF.extensions.customfields.adf-form-field-renderer-base">

<cffunction name="renderControl" returntype="void" access="public">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		var currentValue = arguments.value;	// the field's current value
		var readOnly = (arguments.displayMode EQ 'readonly') ? true : false;
		// Get the Photo Category records
		var photoCategoryData = application.ptPhotoGallery.photoDAO.getCategories();
		
		inputParameters = setDefaultParameters(argumentCollection=arguments);
		
		// Validate the property fields are defined
		if(!Len(currentvalue) AND StructKeyExists(inputParameters, "defaultVal"))
			currentValue = inputParameters.defaultVal;
		
		// Check if a forced category is passed over the params
		if ( StructKeyExists(request.params, "category") AND LEN(request.params.category) ) {
			// Set the current value to defaulted category
			currentValue = request.params.category;
			// hide the field so the category can't be changed
			inputParameters.displayField = "false";
		}
		
		renderJSFunctions(argumentCollection=arguments,fieldParameters=inputParameters);
	</cfscript>
	<cfoutput>
		<!--- Check if we want to display the field or not --->
		<cfif inputParameters.displayField EQ "true">
			<select name="#arguments.fieldName#_select" id="#arguments.fieldName#_select" onchange="#arguments.fieldName#_loadSelection()" <cfif readOnly>disabled="true"</cfif>>
				<option value=""> - Select - </option>
				<cfloop array="#photoCategoryData#" index="currCat">
					<option value="#currCat.values.categoryID#" <cfif currentValue EQ currCat.values.categoryID>selected="selected"</cfif>>#currCat.values.title#</option>
				</cfloop>
			</select>
		</cfif>
		<input type="hidden" name="#arguments.fieldName#" id="#inputParameters.jsFieldID#" value="#currentValue#">
	</cfoutput>
</cffunction>

<cffunction name="renderJSFunctions" returntype="void" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfargument name="fieldParameters" type="struct" required="yes">
	
	<cfscript>
		var inputParameters = Duplicate(arguments.fieldParameters);
	</cfscript>
<cfoutput>
<script type="text/javascript">
<!--
function #arguments.fieldName#_loadSelection(){
	// Get the selected value
	var selectedVal = jQuery("select###arguments.fieldName#_select").find(':selected').val();
	
	// put the selected value into the
	jQuery("input[name=#arguments.fieldName#]").val(selectedVal);
}

function #inputParameters.jsFieldID#_disableFld(){
	jQuery("###arguments.fieldName#_select").attr('disabled', true);
}
// Function to set the field as enabled
function #inputParameters.jsFieldID#_enableFld(){
	// Set a global disable field flag 
	jQuery("###arguments.fieldName#_select").attr('disabled', false);
}
//-->
</script>
</cfoutput>
</cffunction>

<cffunction name="setDefaultParameters" returntype="struct" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		
		if ( NOT StructKeyExists(inputParameters, "displayField") )
			inputParameters.displayField = "true";
		if ( NOT StructKeyExists(inputParameters, "jsFieldID") )
			inputParameters.jsFieldID = arguments.fieldName; 
		
		return inputParameters;
	</cfscript>
</cffunction>

<cfscript>
	private any function getValidationJS(required string formName, required string fieldName, required boolean isRequired)
	{
		if (arguments.isRequired)
			return 'hasValue(document.#arguments.formName#.#arguments.fieldName#, "TEXT")';
		return "";
	}
	
	private string function getValidationMsg()
	{
		return "Please select a value for the #arguments.label# field.";
	}

	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "jQuery");
	}
	public string function loadResourceDependencies()
	{
		application.ADF.scripts.loadJQuery();
	}
</cfscript>

</cfcomponent>
