<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Photo Gallery directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2016.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
	M. Carroll 
Custom Field Type:
	Photo Upload
Name:
	photo_upload_render.cfc
Summary:
	Photo upload field for the PT_Photo_Gallery custom application.
History:
	2009-11-04 - MFC - Created
	2010-08-19 - MFC - Updated the load JQuery and JQuery versions to use the global versioning.
	2012-01-03 - MFC - Added "name" attribute to the Clear button.
	2012-04-10 - MFC - Added button classes.
	2012-08-27 - MFC - Updated logic for the enable/disable of the other form fields.
					   Updated the 'categoryID' arg in the delete AJAX call to get 
					   		from the category field directly.
	2013-07-05 - GAC - Added a new parameter to upload image dialog openLB to flag when replacing an existing image
	2015-02-13 - DMB - Added decipherCPPAGEID to fix up upload_form_url field which changed with the CommonSpot extended URL field change.
	2015-07-15 - GAC - Updated JS and function call to get the upload_form_url from the App config
					 - Converted the URL scoped variables to request.params
	2015-07-16 - DJM - Converted to CFC
	2016-02-26 - DRM - Resource detection support
--->
<cfcomponent displayName="PhotoUpload Render" extends="ADF.extensions.customfields.adf-form-field-renderer-base">

<cffunction name="renderControl" returntype="void" access="public">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		var currentValue = arguments.value;	// the field's current value
		var category = "";
		var callBackFunct = "";
	
		if (StructKeyExists(Request.Params, 'category'))
			category = Request.Params.category;			
			
		if (StructKeyExists(Request.Params, 'callBack'))
			callBackFunct = Request.Params.callBack;

		
		renderJSFunctions(argumentCollection=arguments);
	</cfscript>
	
	<cfoutput>
		<img id="#arguments.fieldName#_photo_disp" src="#currentValue#" width="100" height="100" style="display:block;">
		<input type="button" value="Upload..." name="upload_btn_#arguments.fieldName#" id="upload_btn_#arguments.fieldName#" onclick="#arguments.fieldName#_doOnClick()" class="clsPushButton">
		<input type="button" value="Clear" name="#arguments.fieldName#_clearField" id="#arguments.fieldName#_clearField" class="clsPushButton">

		<!---// hidden field for document location --->
		<input type="hidden" name="#arguments.fieldName#" value="#currentValue#" id="#arguments.fieldName#_upload">
		<input type="hidden" name="#arguments.fieldName#_directoryPath" value="" id="#arguments.fieldName#_directoryPath">
	</cfoutput>
</cffunction>

<cffunction name="renderJSFunctions" returntype="void" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		var appConfig = application.ptPhotoGallery.getAppConfig();
		var uploadFormURL = '';
		
		// Get the UPLOAD FORM URL from the App Configuration
		if ( StructKeyExists(appConfig,"UPLOAD_FORM_URL") AND LEN(TRIM(appConfig.UPLOAD_FORM_URL)) )	
			uploadFormURL = application.ADF.csData.parseCSURL(appConfig.UPLOAD_FORM_URL);
	</cfscript>
<cfoutput>
<script type="text/javascript">
<!--
// Global variables
includeImgGalFlag = "no";

function #arguments.fieldName#validatePhoto()
{
	// get the current value of the hidden field
	// do your validation on the field against the parameters
	if( jQuery('###arguments.fieldName#_upload').val() == "" )
		return false;
	else
		return true;
}

// handle the return
function #arguments.fieldName#setCSURL(inArgs) {
	//alert("CallBack  #arguments.fieldName#setCSURL");
	//console.log(inArgs);
	
	var url = inArgs[0];
	var dir = inArgs[1];
	
	// Sets value for hidden CS URL page
	jQuery('input###arguments.fieldName#_upload').val(url);
	// Set the category id for the uploaded image
	jQuery('input###arguments.fieldName#_directoryPath').val(dir);
	
	// Update the display image for the selection 
	jQuery('img###arguments.fieldName#_photo_disp').attr({ 
	  src: url,
	  width: 100,
	  height: 100
	});
	//jQuery('img###arguments.fieldName#_photo_disp').show(1000);
	
	jQuery('img###arguments.fieldName#_photo_disp').show(1000, function() {
		// Refresh the window size
		lbResizeWindow();
	});
	
	// Disable the Category and Image Gallery Checkbox fields
	#arguments.fieldName#_disableFormFields();
}

function #arguments.fieldName#_doOnClick() {
	// Set the value to the category default
	var categoryVal = '#inputParameters.PHOTOCATEGORY#';
	// Check if the form field is defined or use the default category
	var catFldID = jQuery("input###inputParameters.catFldName#").attr("id");
	
	// Check if the form field is defined or use the default category
	if ( catFldID == "#inputParameters.catFldName#" ) {
		categoryVal = jQuery("input###inputParameters.catFldName#").val();
	}
	
	// Get the value for the currentFileURL value
	var currFile = jQuery("input###arguments.fieldName#_upload").val();
	var imgReplace = 0;
	if ( currFile != "" ) {
		imgReplace = 1;	
	}
	
	// Lightbox URL string
	var lbURL = '#application.ADF.lightboxProxy#?bean=photoUploadService&method=renderPhotoUploadForm&category='+categoryVal+'&fieldName=#arguments.fieldName#&title=Upload New Photo';
	
	// Open the upload lightbox window
	openLB(lbURL);
}

// Disable the Category and Image Gallery Checkbox fields
function #arguments.fieldName#_disableFormFields(){
	// Disable the category field
	<cfif LEN(inputParameters.catFldName)>
		#inputParameters.catFldName#_disableFld();
	</cfif>
	
	// Disable the Image Gallery Checkbox field
	// TODO - Fix the includeImgGalleryFldName to be enabled/disabled
	<!--- <cfif LEN(inputParameters.includeImgGalleryFldName)>
		#inputParameters.includeImgGalleryFldName#_disableFld();
	</cfif> --->
}

// Enable the Category and Image Gallery Checkbox fields
function #arguments.fieldName#_enableFormFields(){
	// Enable the category field
	<cfif LEN(inputParameters.catFldName)>
		#inputParameters.catFldName#_enableFld();
	</cfif>
	
	// Enable the Image Gallery Checkbox field
	// TODO - Fix the includeImgGalleryFldName to be enabled/disabled
	<!--- <cfif LEN(inputParameters.includeImgGalleryFldName)>
		#inputParameters.includeImgGalleryFldName#_enableFld();
	</cfif> --->
}

jQuery(document).ready(function(){
	
	// Load the Category value for the photo into the form field
	// Verify that the category fld is empty then default the category 
	if ( jQuery("input###inputParameters.catFldName#").val() == '' )
		jQuery("input###inputParameters.catFldName#").val('#inputParameters.photoCategory#');
	
	// Set a global Category value variable
	categoryVal = jQuery("input###inputParameters.catFldName#").val();
	
	// check to see if the uploaded file still exists on the server
	// Get the value for the field value
	var currentFileURL = jQuery("input###arguments.fieldName#_upload").val();
	if (currentFileURL != "") {
		// Check that the file exists on the server
		jQuery.get( '#application.ADF.ajaxProxy#',
		{ 	
			bean: 'photoService',
			method: 'verifyUploadsFile',
			inFile: currentFileURL,
			categoryID: '#inputParameters.photoCategory#',
			deleteFile: false
		},
		function(msg){
			if (msg == "false"){
				// Clear the field value
				jQuery("input###arguments.fieldName#_upload").val("");
				jQuery("input###arguments.fieldName#_directoryPath").val("");
				// Clear the Image Gallery Page ID field
				// if the photo was stored into the image gallery, then store the page id
				if ( includeImgGalFlag == 'yes' ) {
					// Sets value for hidden Image Gallery PageID field
					#inputParameters.includeImgGalleryFldName#_setImgGalPageID(0);
				}
				
				// Clear the display upload for the selection
				jQuery('img###arguments.fieldName#_photo_disp').hide();
				
				// Refresh the window size
				lbResizeWindow();
			}
			else {
				// We Have a valid photo
				// Hide the category and image gallery fields
				#arguments.fieldName#_disableFormFields();
			}
		});
	}
	else {
		// clear the img field and hide
		jQuery('img###arguments.fieldName#_photo_disp').attr({ 
		  src: '',
		  width: 100,
		  height: 100
		});
		jQuery('img###arguments.fieldName#_photo_disp').hide();
		lbResizeWindow();
	}
	
	// Clear the selected file field
	jQuery('###arguments.fieldName#_clearField').click( function(){
		
		// Get the value for the field value
		var currentFileURL = jQuery("input###arguments.fieldName#_upload").val();
		if (currentFileURL != "") {
			// confirmation to clear the image
			var clear = confirm("Attention: This photo will be deleted without saving the form.\n\nAre you sure you want to delete this document?");
			if (clear){
				var imgGalPageID = 0;
				// Get the Image Gallery Page ID Field value
				if ( includeImgGalFlag == 'yes' )
				{
					// Sets value for hidden Image Gallery PageID field
					imgGalPageID = #inputParameters.includeImgGalleryFldName#_getImgGalPageID();
				}
				
				// Delete the file record
				// Updated the 'categoryID' arg to get from the category field directly.
				jQuery.get( '#application.ADF.ajaxProxy#',
				{ 	
					bean: 'photoService',
					method: 'verifyUploadsFile',
					inFile: currentFileURL,
					categoryID: jQuery("input###inputParameters.catFldName#").val(),
					deleteFile: true,
					imgGalPageID: imgGalPageID
				},
				function(msg){
					if (msg == "true"){
						// Clear the field value
						jQuery("input###arguments.fieldName#_upload").val("");
						jQuery("input###arguments.fieldName#_directoryPath").val("");
						// Clear the Image Gallery Page ID field
						if ( includeImgGalFlag == 'yes' ) {
							// Sets value for hidden Image Gallery PageID field
							#inputParameters.includeImgGalleryFldName#_setImgGalPageID(0);
						}
						// Clear the display upload for the selection
						jQuery('img###arguments.fieldName#_photo_disp').hide(1000, function() {
							// Resize Window
							lbResizeWindow();
						});
						
						// Enable the Category and Image Gallery Checkbox fields
						#arguments.fieldName#_enableFormFields();								
					}
				});
			}
		}			
	});
});
//-->
</script>
</cfoutput>
</cffunction>

<cfscript>
	private any function getValidationJS(required string formName, required string fieldName, required boolean isRequired)
	{
		if (arguments.isRequired)
			return '#arguments.fieldName#validatePhoto()';
		return "";
	}
	
	private string function getValidationMsg()
	{
		return "Please upload a Photo.";
	}


	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "jQuery,ADFLightbox");
	}
	public string function loadResourceDependencies()
	{
		application.ptPhotoGallery.scripts.loadJQuery();
		application.ptPhotoGallery.scripts.loadADFLightbox();
	}
</cfscript>

</cfcomponent>